@@ -180,7 +180,7 @@ def test_dbscan_metric_params():
             min_samples=min_samples,
             algorithm="ball_tree",
         ).fit(X)
-    assert not warns
+    assert not warns, warns[0].message
     core_sample_1, labels_1 = db.core_sample_indices_, db.labels_
 
     # Test that sample labels are the same as passing Minkowski 'p' directly
@@ -272,11 +272,8 @@ def test_input_validation():
 @pytest.mark.parametrize(
     "args",
     [
-        {"eps": -1.0},
         {"algorithm": "blah"},
         {"metric": "blah"},
-        {"leaf_size": -1},
-        {"p": -1},
     ],
 )
 def test_dbscan_badargs(args):
@@ -428,3 +425,36 @@ def test_dbscan_precomputed_metric_with_initial_rows_zero():
     matrix = sparse.csr_matrix(ar)
     labels = DBSCAN(eps=0.2, metric="precomputed", min_samples=2).fit(matrix).labels_
     assert_array_equal(labels, [-1, -1, 0, 0, 0, 1, 1])
+
+
+@pytest.mark.parametrize(
+    "params, err_type, err_msg",
+    [
+        ({"eps": -1.0}, ValueError, "eps == -1.0, must be > 0.0."),
+        ({"eps": 0.0}, ValueError, "eps == 0.0, must be > 0.0."),
+        ({"min_samples": 0}, ValueError, "min_samples == 0, must be >= 1."),
+        (
+            {"min_samples": 1.5},
+            TypeError,
+            "min_samples must be an instance of int, not float.",
+        ),
+        ({"min_samples": -2}, ValueError, "min_samples == -2, must be >= 1."),
+        ({"leaf_size": 0}, ValueError, "leaf_size == 0, must be >= 1."),
+        (
+            {"leaf_size": 2.5},
+            TypeError,
+            "leaf_size must be an instance of int, not float.",
+        ),
+        ({"leaf_size": -3}, ValueError, "leaf_size == -3, must be >= 1."),
+        ({"p": -2}, ValueError, "p == -2, must be >= 0.0."),
+        (
+            {"n_jobs": 2.5},
+            TypeError,
+            "n_jobs must be an instance of int, not float.",
+        ),
+    ],
+)
+def test_dbscan_params_validation(params, err_type, err_msg):
+    """Check the parameters validation in `DBSCAN`."""
+    with pytest.raises(err_type, match=err_msg):
+        DBSCAN(**params).fit(X)
