@@ -16,7 +16,6 @@ from sklearn.feature_extraction.image import (
     PatchExtractor,
     _extract_patches,
 )
-from sklearn.utils._testing import ignore_warnings
 
 
 def test_img_to_graph():
@@ -56,7 +55,7 @@ def test_grid_to_graph():
     mask = np.zeros((size, size), dtype=bool)
     mask[0:roi_size, 0:roi_size] = True
     mask[-roi_size:, -roi_size:] = True
-    mask = mask.reshape(size ** 2)
+    mask = mask.reshape(size**2)
     A = grid_to_graph(n_x=size, n_y=size, mask=mask, return_as=np.ndarray)
     assert connected_components(A)[0] == 2
 
@@ -83,15 +82,8 @@ def test_grid_to_graph():
     assert A.dtype == np.float64
 
 
-@ignore_warnings(category=DeprecationWarning)  # scipy deprecation inside face
 def test_connect_regions():
-    try:
-        face = sp.face(gray=True)
-    except AttributeError:
-        # Newer versions of scipy have face in misc
-        from scipy import misc
-
-        face = misc.face(gray=True)
+    face = sp.misc.face(gray=True)
     # subsample by 4 to reduce run time
     face = face[::4, ::4]
     for thr in (50, 150):
@@ -100,15 +92,8 @@ def test_connect_regions():
         assert ndimage.label(mask)[1] == connected_components(graph)[0]
 
 
-@ignore_warnings(category=DeprecationWarning)  # scipy deprecation inside face
 def test_connect_regions_with_grid():
-    try:
-        face = sp.face(gray=True)
-    except AttributeError:
-        # Newer versions of scipy have face in misc
-        from scipy import misc
-
-        face = misc.face(gray=True)
+    face = sp.misc.face(gray=True)
 
     # subsample by 4 to reduce run time
     face = face[::4, ::4]
@@ -332,7 +317,7 @@ def test_extract_patches_strided():
     expected_views = expected_views_1D + expected_views_2D + expected_views_3D
     last_patches = last_patch_1D + last_patch_2D + last_patch_3D
 
-    for (image_shape, patch_size, patch_step, expected_view, last_patch) in zip(
+    for image_shape, patch_size, patch_step, expected_view, last_patch in zip(
         image_shapes, patch_sizes, patch_steps, expected_views, last_patches
     ):
         image = np.arange(np.prod(image_shape)).reshape(image_shape)
