@@ -9,13 +9,17 @@ from scipy.linalg import eigh, svd, qr, solve
 from scipy.sparse import eye, csr_matrix
 from scipy.sparse.linalg import eigsh
 
-from ..base import BaseEstimator, TransformerMixin, _UnstableArchMixin
+from ..base import (
+    BaseEstimator,
+    TransformerMixin,
+    _UnstableArchMixin,
+    _ClassNamePrefixFeaturesOutMixin,
+)
 from ..utils import check_random_state, check_array
 from ..utils._arpack import _init_arpack_v0
 from ..utils.extmath import stable_cumsum
 from ..utils.validation import check_is_fitted
 from ..utils.validation import FLOAT_DTYPES
-from ..utils.validation import _deprecate_positional_args
 from ..neighbors import NearestNeighbors
 
 
@@ -67,11 +71,12 @@ def barycenter_weights(X, Y, indices, reg=1e-3):
             R = reg * trace
         else:
             R = reg
-        G.flat[::n_neighbors + 1] += R
+        G.flat[:: n_neighbors + 1] += R
         w = solve(G, v, sym_pos=True)
         B[i, :] = w / np.sum(w)
     return B
 
+
 def barycenter_kneighbors_graph(X, n_neighbors, reg=1e-3, n_jobs=None):
     """Computes the barycenter weighted graph of k-Neighbors for points in X
 
@@ -111,12 +116,12 @@ def barycenter_kneighbors_graph(X, n_neighbors, reg=1e-3, n_jobs=None):
     ind = knn.kneighbors(X, return_distance=False)[:, 1:]
     data = barycenter_weights(X, X, ind, reg=reg)
     indptr = np.arange(0, n_samples * n_neighbors + 1, n_neighbors)
-    return csr_matrix((data.ravel(), ind.ravel(), indptr),
-                      shape=(n_samples, n_samples))
+    return csr_matrix((data.ravel(), ind.ravel(), indptr), shape=(n_samples, n_samples))
 
 
-def null_space(M, k, k_skip=1, eigen_solver='arpack', tol=1E-6, max_iter=100,
-               random_state=None):
+def null_space(
+    M, k, k_skip=1, eigen_solver="arpack", tol=1e-6, max_iter=100, random_state=None
+):
     """
     Find the null space of a matrix M.
 
@@ -154,20 +159,20 @@ def null_space(M, k, k_skip=1, eigen_solver='arpack', tol=1E-6, max_iter=100,
     random_state : int, RandomState instance, default=None
         Determines the random number generator when ``solver`` == 'arpack'.
         Pass an int for reproducible results across multiple function calls.
-        See :term: `Glossary <random_state>`.
+        See :term:`Glossary <random_state>`.
     """
-    if eigen_solver == 'auto':
+    if eigen_solver == "auto":
         if M.shape[0] > 200 and k + k_skip < 10:
-            eigen_solver = 'arpack'
+            eigen_solver = "arpack"
         else:
-            eigen_solver = 'dense'
+            eigen_solver = "dense"
 
-    if eigen_solver == 'arpack':
+    if eigen_solver == "arpack":
         v0 = _init_arpack_v0(M.shape[0], random_state)
         try:
-            eigen_values, eigen_vectors = eigsh(M, k + k_skip, sigma=0.0,
-                                                tol=tol, maxiter=max_iter,
-                                                v0=v0)
+            eigen_values, eigen_vectors = eigsh(
+                M, k + k_skip, sigma=0.0, tol=tol, maxiter=max_iter, v0=v0
+            )
         except RuntimeError as e:
             raise ValueError(
                 "Error in determining null-space with ARPACK. Error message: "
@@ -178,22 +183,33 @@ def null_space(M, k, k_skip=1, eigen_solver='arpack', tol=1E-6, max_iter=100,
             ) from e
 
         return eigen_vectors[:, k_skip:], np.sum(eigen_values[k_skip:])
-    elif eigen_solver == 'dense':
-        if hasattr(M, 'toarray'):
+    elif eigen_solver == "dense":
+        if hasattr(M, "toarray"):
             M = M.toarray()
         eigen_values, eigen_vectors = eigh(
-            M, eigvals=(k_skip, k + k_skip - 1), overwrite_a=True)
+            M, eigvals=(k_skip, k + k_skip - 1), overwrite_a=True
+        )
         index = np.argsort(np.abs(eigen_values))
         return eigen_vectors[:, index], np.sum(eigen_values)
     else:
         raise ValueError("Unrecognized eigen_solver '%s'" % eigen_solver)
 
 
-@_deprecate_positional_args
 def locally_linear_embedding(
-        X, *, n_neighbors, n_components, reg=1e-3, eigen_solver='auto',
-        tol=1e-6, max_iter=100, method='standard', hessian_tol=1E-4,
-        modified_tol=1E-12, random_state=None, n_jobs=None):
+    X,
+    *,
+    n_neighbors,
+    n_components,
+    reg=1e-3,
+    eigen_solver="auto",
+    tol=1e-6,
+    max_iter=100,
+    method="standard",
+    hessian_tol=1e-4,
+    modified_tol=1e-12,
+    random_state=None,
+    n_jobs=None,
+):
     """Perform a Locally Linear Embedding analysis on the data.
 
     Read more in the :ref:`User Guide <locally_linear_embedding>`.
@@ -257,7 +273,7 @@ def locally_linear_embedding(
     random_state : int, RandomState instance, default=None
         Determines the random number generator when ``solver`` == 'arpack'.
         Pass an int for reproducible results across multiple function calls.
-        See :term: `Glossary <random_state>`.
+        See :term:`Glossary <random_state>`.
 
     n_jobs : int or None, default=None
         The number of parallel jobs to run for neighbors search.
@@ -289,10 +305,10 @@ def locally_linear_embedding(
         dimensionality reduction via tangent space alignment.
         Journal of Shanghai Univ.  8:406 (2004)
     """
-    if eigen_solver not in ('auto', 'arpack', 'dense'):
+    if eigen_solver not in ("auto", "arpack", "dense"):
         raise ValueError("unrecognized eigen_solver '%s'" % eigen_solver)
 
-    if method not in ('standard', 'hessian', 'modified', 'ltsa'):
+    if method not in ("standard", "hessian", "modified", "ltsa"):
         raise ValueError("unrecognized method '%s'" % method)
 
     nbrs = NearestNeighbors(n_neighbors=n_neighbors + 1, n_jobs=n_jobs)
@@ -302,23 +318,24 @@ def locally_linear_embedding(
     N, d_in = X.shape
 
     if n_components > d_in:
-        raise ValueError("output dimension must be less than or equal "
-                         "to input dimension")
+        raise ValueError(
+            "output dimension must be less than or equal to input dimension"
+        )
     if n_neighbors >= N:
         raise ValueError(
-            "Expected n_neighbors <= n_samples, "
-            " but n_samples = %d, n_neighbors = %d" %
-            (N, n_neighbors)
+            "Expected n_neighbors <= n_samples,  but n_samples = %d, n_neighbors = %d"
+            % (N, n_neighbors)
         )
 
     if n_neighbors <= 0:
         raise ValueError("n_neighbors must be positive")
 
-    M_sparse = (eigen_solver != 'dense')
+    M_sparse = eigen_solver != "dense"
 
-    if method == 'standard':
+    if method == "standard":
         W = barycenter_kneighbors_graph(
-            nbrs, n_neighbors=n_neighbors, reg=reg, n_jobs=n_jobs)
+            nbrs, n_neighbors=n_neighbors, reg=reg, n_jobs=n_jobs
+        )
 
         # we'll compute M = (I-W)'(I-W)
         # depending on the solver, we'll do this differently
@@ -327,18 +344,21 @@ def locally_linear_embedding(
             M = (M.T * M).tocsr()
         else:
             M = (W.T * W - W.T - W).toarray()
-            M.flat[::M.shape[0] + 1] += 1  # W = W - I = W - I
+            M.flat[:: M.shape[0] + 1] += 1  # W = W - I = W - I
 
-    elif method == 'hessian':
+    elif method == "hessian":
         dp = n_components * (n_components + 1) // 2
 
         if n_neighbors <= n_components + dp:
-            raise ValueError("for method='hessian', n_neighbors must be "
-                             "greater than "
-                             "[n_components * (n_components + 3) / 2]")
+            raise ValueError(
+                "for method='hessian', n_neighbors must be "
+                "greater than "
+                "[n_components * (n_components + 3) / 2]"
+            )
 
-        neighbors = nbrs.kneighbors(X, n_neighbors=n_neighbors + 1,
-                                    return_distance=False)
+        neighbors = nbrs.kneighbors(
+            X, n_neighbors=n_neighbors + 1, return_distance=False
+        )
         neighbors = neighbors[:, 1:]
 
         Yi = np.empty((n_neighbors, 1 + n_components + dp), dtype=np.float64)
@@ -346,7 +366,7 @@ def locally_linear_embedding(
 
         M = np.zeros((N, N), dtype=np.float64)
 
-        use_svd = (n_neighbors > d_in)
+        use_svd = n_neighbors > d_in
 
         for i in range(N):
             Gi = X[neighbors[i]]
@@ -359,17 +379,16 @@ def locally_linear_embedding(
                 Ci = np.dot(Gi, Gi.T)
                 U = eigh(Ci)[1][:, ::-1]
 
-            Yi[:, 1:1 + n_components] = U[:, :n_components]
+            Yi[:, 1 : 1 + n_components] = U[:, :n_components]
 
             j = 1 + n_components
             for k in range(n_components):
-                Yi[:, j:j + n_components - k] = (U[:, k:k + 1] *
-                                                 U[:, k:n_components])
+                Yi[:, j : j + n_components - k] = U[:, k : k + 1] * U[:, k:n_components]
                 j += n_components - k
 
             Q, R = qr(Yi)
 
-            w = Q[:, n_components + 1:]
+            w = Q[:, n_components + 1 :]
             S = w.sum(0)
 
             S[np.where(abs(S) < hessian_tol)] = 1
@@ -381,13 +400,13 @@ def locally_linear_embedding(
         if M_sparse:
             M = csr_matrix(M)
 
-    elif method == 'modified':
+    elif method == "modified":
         if n_neighbors < n_components:
-            raise ValueError("modified LLE requires "
-                             "n_neighbors >= n_components")
+            raise ValueError("modified LLE requires n_neighbors >= n_components")
 
-        neighbors = nbrs.kneighbors(X, n_neighbors=n_neighbors + 1,
-                                    return_distance=False)
+        neighbors = nbrs.kneighbors(
+            X, n_neighbors=n_neighbors + 1, return_distance=False
+        )
         neighbors = neighbors[:, 1:]
 
         # find the eigenvectors and eigenvalues of each local covariance
@@ -398,13 +417,12 @@ def locally_linear_embedding(
         evals = np.zeros([N, nev])
 
         # choose the most efficient way to find the eigenvectors
-        use_svd = (n_neighbors > d_in)
+        use_svd = n_neighbors > d_in
 
         if use_svd:
             for i in range(N):
                 X_nbrs = X[neighbors[i]] - X[i]
-                V[i], evals[i], _ = svd(X_nbrs,
-                                        full_matrices=True)
+                V[i], evals[i], _ = svd(X_nbrs, full_matrices=True)
             evals **= 2
         else:
             for i in range(N):
@@ -417,7 +435,7 @@ def locally_linear_embedding(
         # find regularized weights: this is like normal LLE.
         # because we've already computed the SVD of each covariance matrix,
         # it's faster to use this rather than np.linalg.solve
-        reg = 1E-3 * evals.sum(1)
+        reg = 1e-3 * evals.sum(1)
 
         tmp = np.dot(V.transpose(0, 2, 1), np.ones(n_neighbors))
         tmp[:, :nev] /= evals + reg[:, None]
@@ -450,7 +468,7 @@ def locally_linear_embedding(
             s_i = s_range[i]
 
             # select bottom s_i eigenvectors and calculate alpha
-            Vi = V[i, :, n_neighbors - s_i:]
+            Vi = V[i, :, n_neighbors - s_i :]
             alpha_i = np.linalg.norm(Vi.sum(0)) / np.sqrt(s_i)
 
             # compute Householder matrix which satisfies
@@ -469,8 +487,7 @@ def locally_linear_embedding(
             # Then the weight matrix is
             #  >> Wi = np.dot(Vi,Hi) + (1-alpha_i) * w_reg[i,:,None]
             # We do this much more efficiently:
-            Wi = (Vi - 2 * np.outer(np.dot(Vi, h), h) +
-                  (1 - alpha_i) * w_reg[i, :, None])
+            Wi = Vi - 2 * np.outer(np.dot(Vi, h), h) + (1 - alpha_i) * w_reg[i, :, None]
 
             # Update M as follows:
             # >> W_hat = np.zeros( (N,s_i) )
@@ -488,14 +505,15 @@ def locally_linear_embedding(
         if M_sparse:
             M = csr_matrix(M)
 
-    elif method == 'ltsa':
-        neighbors = nbrs.kneighbors(X, n_neighbors=n_neighbors + 1,
-                                    return_distance=False)
+    elif method == "ltsa":
+        neighbors = nbrs.kneighbors(
+            X, n_neighbors=n_neighbors + 1, return_distance=False
+        )
         neighbors = neighbors[:, 1:]
 
         M = np.zeros((N, N))
 
-        use_svd = (n_neighbors > d_in)
+        use_svd = n_neighbors > d_in
 
         for i in range(N):
             Xi = X[neighbors[i]]
@@ -510,7 +528,7 @@ def locally_linear_embedding(
 
             Gi = np.zeros((n_neighbors, n_components + 1))
             Gi[:, 1:] = v[:, :n_components]
-            Gi[:, 0] = 1. / np.sqrt(n_neighbors)
+            Gi[:, 0] = 1.0 / np.sqrt(n_neighbors)
 
             GiGiT = np.dot(Gi, Gi.T)
 
@@ -518,78 +536,91 @@ def locally_linear_embedding(
             M[nbrs_x, nbrs_y] -= GiGiT
             M[neighbors[i], neighbors[i]] += 1
 
-    return null_space(M, n_components, k_skip=1, eigen_solver=eigen_solver,
-                      tol=tol, max_iter=max_iter, random_state=random_state)
+    return null_space(
+        M,
+        n_components,
+        k_skip=1,
+        eigen_solver=eigen_solver,
+        tol=tol,
+        max_iter=max_iter,
+        random_state=random_state,
+    )
 
 
-class LocallyLinearEmbedding(TransformerMixin,
-                             _UnstableArchMixin, BaseEstimator):
-    """Locally Linear Embedding
+class LocallyLinearEmbedding(
+    _ClassNamePrefixFeaturesOutMixin,
+    TransformerMixin,
+    _UnstableArchMixin,
+    BaseEstimator,
+):
+    """Locally Linear Embedding.
 
     Read more in the :ref:`User Guide <locally_linear_embedding>`.
 
     Parameters
     ----------
     n_neighbors : int, default=5
-        number of neighbors to consider for each point.
+        Number of neighbors to consider for each point.
 
     n_components : int, default=2
-        number of coordinates for the manifold
+        Number of coordinates for the manifold.
 
     reg : float, default=1e-3
-        regularization constant, multiplies the trace of the local covariance
+        Regularization constant, multiplies the trace of the local covariance
         matrix of the distances.
 
     eigen_solver : {'auto', 'arpack', 'dense'}, default='auto'
-        auto : algorithm will attempt to choose the best method for input data
+        The solver used to compute the eigenvectors. The available options are:
 
-        arpack : use arnoldi iteration in shift-invert mode.
-                    For this method, M may be a dense matrix, sparse matrix,
-                    or general linear operator.
-                    Warning: ARPACK can be unstable for some problems.  It is
-                    best to try several random seeds in order to check results.
+        - `'auto'` : algorithm will attempt to choose the best method for input
+          data.
+        - `'arpack'` : use arnoldi iteration in shift-invert mode. For this
+          method, M may be a dense matrix, sparse matrix, or general linear
+          operator.
+        - `'dense'`  : use standard dense matrix operations for the eigenvalue
+          decomposition. For this method, M must be an array or matrix type.
+          This method should be avoided for large problems.
 
-        dense  : use standard dense matrix operations for the eigenvalue
-                    decomposition.  For this method, M must be an array
-                    or matrix type.  This method should be avoided for
-                    large problems.
+        .. warning::
+           ARPACK can be unstable for some problems.  It is best to try several
+           random seeds in order to check results.
 
     tol : float, default=1e-6
         Tolerance for 'arpack' method
         Not used if eigen_solver=='dense'.
 
     max_iter : int, default=100
-        maximum number of iterations for the arpack solver.
+        Maximum number of iterations for the arpack solver.
         Not used if eigen_solver=='dense'.
 
     method : {'standard', 'hessian', 'modified', 'ltsa'}, default='standard'
-        standard : use the standard locally linear embedding algorithm.  see
-                   reference [1]
-        hessian  : use the Hessian eigenmap method. This method requires
-                   ``n_neighbors > n_components * (1 + (n_components + 1) / 2``
-                   see reference [2]
-        modified : use the modified locally linear embedding algorithm.
-                   see reference [3]
-        ltsa     : use local tangent space alignment algorithm
-                   see reference [4]
+        - `standard`: use the standard locally linear embedding algorithm. see
+          reference [1]_
+        - `hessian`: use the Hessian eigenmap method. This method requires
+          ``n_neighbors > n_components * (1 + (n_components + 1) / 2``. see
+          reference [2]_
+        - `modified`: use the modified locally linear embedding algorithm.
+          see reference [3]_
+        - `ltsa`: use local tangent space alignment algorithm. see
+          reference [4]_
 
     hessian_tol : float, default=1e-4
         Tolerance for Hessian eigenmapping method.
-        Only used if ``method == 'hessian'``
+        Only used if ``method == 'hessian'``.
 
     modified_tol : float, default=1e-12
         Tolerance for modified LLE method.
-        Only used if ``method == 'modified'``
+        Only used if ``method == 'modified'``.
 
     neighbors_algorithm : {'auto', 'brute', 'kd_tree', 'ball_tree'}, \
                           default='auto'
-        algorithm to use for nearest neighbors search,
-        passed to neighbors.NearestNeighbors instance
+        Algorithm to use for nearest neighbors search, passed to
+        :class:`~sklearn.neighbors.NearestNeighbors` instance.
 
     random_state : int, RandomState instance, default=None
         Determines the random number generator when
         ``eigen_solver`` == 'arpack'. Pass an int for reproducible results
-        across multiple function calls. See :term: `Glossary <random_state>`.
+        across multiple function calls. See :term:`Glossary <random_state>`.
 
     n_jobs : int or None, default=None
         The number of parallel jobs to run.
@@ -605,21 +636,26 @@ class LocallyLinearEmbedding(TransformerMixin,
     reconstruction_error_ : float
         Reconstruction error associated with `embedding_`
 
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
     nbrs_ : NearestNeighbors object
         Stores nearest neighbors instance, including BallTree or KDtree
         if applicable.
 
-    Examples
+    See Also
     --------
-    >>> from sklearn.datasets import load_digits
-    >>> from sklearn.manifold import LocallyLinearEmbedding
-    >>> X, _ = load_digits(return_X_y=True)
-    >>> X.shape
-    (1797, 64)
-    >>> embedding = LocallyLinearEmbedding(n_components=2)
-    >>> X_transformed = embedding.fit_transform(X[:100])
-    >>> X_transformed.shape
-    (100, 2)
+    SpectralEmbedding : Spectral embedding for non-linear dimensionality
+        reduction.
+    TSNE : Distributed Stochastic Neighbor Embedding.
 
     References
     ----------
@@ -635,12 +671,36 @@ class LocallyLinearEmbedding(TransformerMixin,
     .. [4] Zhang, Z. & Zha, H. Principal manifolds and nonlinear
         dimensionality reduction via tangent space alignment.
         Journal of Shanghai Univ.  8:406 (2004)
+
+    Examples
+    --------
+    >>> from sklearn.datasets import load_digits
+    >>> from sklearn.manifold import LocallyLinearEmbedding
+    >>> X, _ = load_digits(return_X_y=True)
+    >>> X.shape
+    (1797, 64)
+    >>> embedding = LocallyLinearEmbedding(n_components=2)
+    >>> X_transformed = embedding.fit_transform(X[:100])
+    >>> X_transformed.shape
+    (100, 2)
     """
-    @_deprecate_positional_args
-    def __init__(self, *, n_neighbors=5, n_components=2, reg=1E-3,
-                 eigen_solver='auto', tol=1E-6, max_iter=100,
-                 method='standard', hessian_tol=1E-4, modified_tol=1E-12,
-                 neighbors_algorithm='auto', random_state=None, n_jobs=None):
+
+    def __init__(
+        self,
+        *,
+        n_neighbors=5,
+        n_components=2,
+        reg=1e-3,
+        eigen_solver="auto",
+        tol=1e-6,
+        max_iter=100,
+        method="standard",
+        hessian_tol=1e-4,
+        modified_tol=1e-12,
+        neighbors_algorithm="auto",
+        random_state=None,
+        n_jobs=None,
+    ):
         self.n_neighbors = n_neighbors
         self.n_components = n_components
         self.reg = reg
@@ -655,35 +715,46 @@ class LocallyLinearEmbedding(TransformerMixin,
         self.n_jobs = n_jobs
 
     def _fit_transform(self, X):
-        self.nbrs_ = NearestNeighbors(n_neighbors=self.n_neighbors,
-                                      algorithm=self.neighbors_algorithm,
-                                      n_jobs=self.n_jobs)
+        self.nbrs_ = NearestNeighbors(
+            n_neighbors=self.n_neighbors,
+            algorithm=self.neighbors_algorithm,
+            n_jobs=self.n_jobs,
+        )
 
         random_state = check_random_state(self.random_state)
         X = self._validate_data(X, dtype=float)
         self.nbrs_.fit(X)
-        self.embedding_, self.reconstruction_error_ = \
-            locally_linear_embedding(
-                X=self.nbrs_, n_neighbors=self.n_neighbors,
-                n_components=self.n_components,
-                eigen_solver=self.eigen_solver, tol=self.tol,
-                max_iter=self.max_iter, method=self.method,
-                hessian_tol=self.hessian_tol, modified_tol=self.modified_tol,
-                random_state=random_state, reg=self.reg, n_jobs=self.n_jobs)
+        self.embedding_, self.reconstruction_error_ = locally_linear_embedding(
+            X=self.nbrs_,
+            n_neighbors=self.n_neighbors,
+            n_components=self.n_components,
+            eigen_solver=self.eigen_solver,
+            tol=self.tol,
+            max_iter=self.max_iter,
+            method=self.method,
+            hessian_tol=self.hessian_tol,
+            modified_tol=self.modified_tol,
+            random_state=random_state,
+            reg=self.reg,
+            n_jobs=self.n_jobs,
+        )
+        self._n_features_out = self.embedding_.shape[1]
 
     def fit(self, X, y=None):
-        """Compute the embedding vectors for data X
+        """Compute the embedding vectors for data X.
 
         Parameters
         ----------
-        X : array-like of shape [n_samples, n_features]
-            training set.
+        X : array-like of shape (n_samples, n_features)
+            Training set.
 
         y : Ignored
+            Not used, present here for API consistency by convention.
 
         Returns
         -------
-        self : returns an instance of self.
+        self : object
+            Fitted `LocallyLinearEmbedding` class instance.
         """
         self._fit_transform(X)
         return self
@@ -693,14 +764,16 @@ class LocallyLinearEmbedding(TransformerMixin,
 
         Parameters
         ----------
-        X : array-like of shape [n_samples, n_features]
-            training set.
+        X : array-like of shape (n_samples, n_features)
+            Training set.
 
         y : Ignored
+            Not used, present here for API consistency by convention.
 
         Returns
         -------
         X_new : array-like, shape (n_samples, n_components)
+            Returns the instance itself.
         """
         self._fit_transform(X)
         return self.embedding_
@@ -712,21 +785,24 @@ class LocallyLinearEmbedding(TransformerMixin,
         Parameters
         ----------
         X : array-like of shape (n_samples, n_features)
+            Training set.
 
         Returns
         -------
-        X_new : array, shape = [n_samples, n_components]
+        X_new : ndarray of shape (n_samples, n_components)
+            Returns the instance itself.
 
         Notes
         -----
         Because of scaling performed by this method, it is discouraged to use
-        it together with methods that are not scale-invariant (like SVMs)
+        it together with methods that are not scale-invariant (like SVMs).
         """
         check_is_fitted(self)
 
-        X = check_array(X)
-        ind = self.nbrs_.kneighbors(X, n_neighbors=self.n_neighbors,
-                                    return_distance=False)
+        X = self._validate_data(X, reset=False)
+        ind = self.nbrs_.kneighbors(
+            X, n_neighbors=self.n_neighbors, return_distance=False
+        )
         weights = barycenter_weights(X, self.nbrs_._fit_X, ind, reg=self.reg)
         X_new = np.empty((X.shape[0], self.n_components))
         for i in range(X.shape[0]):
