@@ -23,14 +23,33 @@ from functools import partial
 from collections import Counter
 
 import numpy as np
+import copy
+import warnings
 
-from . import (r2_score, median_absolute_error, max_error, mean_absolute_error,
-               mean_squared_error, mean_squared_log_error,
-               mean_poisson_deviance, mean_gamma_deviance, accuracy_score,
-               top_k_accuracy_score, f1_score, roc_auc_score,
-               average_precision_score, precision_score, recall_score,
-               log_loss, balanced_accuracy_score, explained_variance_score,
-               brier_score_loss, jaccard_score, mean_absolute_percentage_error)
+from . import (
+    r2_score,
+    median_absolute_error,
+    max_error,
+    mean_absolute_error,
+    mean_squared_error,
+    mean_squared_log_error,
+    mean_poisson_deviance,
+    mean_gamma_deviance,
+    accuracy_score,
+    top_k_accuracy_score,
+    f1_score,
+    roc_auc_score,
+    average_precision_score,
+    precision_score,
+    recall_score,
+    log_loss,
+    balanced_accuracy_score,
+    explained_variance_score,
+    brier_score_loss,
+    jaccard_score,
+    mean_absolute_percentage_error,
+    matthews_corrcoef,
+)
 
 from .cluster import adjusted_rand_score
 from .cluster import rand_score
@@ -43,7 +62,6 @@ from .cluster import normalized_mutual_info_score
 from .cluster import fowlkes_mallows_score
 
 from ..utils.multiclass import type_of_target
-from ..utils.validation import _deprecate_positional_args
 from ..base import is_regressor
 
 
@@ -73,6 +91,7 @@ class _MultimetricScorer:
     scorers : dict
         Dictionary mapping names to callable scorers.
     """
+
     def __init__(self, **scorers):
         self._scorers = scorers
 
@@ -84,8 +103,7 @@ class _MultimetricScorer:
 
         for name, scorer in self._scorers.items():
             if isinstance(scorer, _BaseScorer):
-                score = scorer._score(cached_call, estimator,
-                                      *args, **kwargs)
+                score = scorer._score(cached_call, estimator, *args, **kwargs)
             else:
                 score = scorer(estimator, *args, **kwargs)
             scores[name] = score
@@ -109,15 +127,16 @@ class _MultimetricScorer:
 
         counter = Counter([type(v) for v in self._scorers.values()])
 
-        if any(counter[known_type] > 1 for known_type in
-               [_PredictScorer, _ProbaScorer, _ThresholdScorer]):
+        if any(
+            counter[known_type] > 1
+            for known_type in [_PredictScorer, _ProbaScorer, _ThresholdScorer]
+        ):
             return True
 
         if counter[_ThresholdScorer]:
             if is_regressor(estimator) and counter[_PredictScorer]:
                 return True
-            elif (counter[_ProbaScorer] and
-                  not hasattr(estimator, "decision_function")):
+            elif counter[_ProbaScorer] and not hasattr(estimator, "decision_function"):
                 return True
         return False
 
@@ -131,9 +150,7 @@ class _BaseScorer:
     @staticmethod
     def _check_pos_label(pos_label, classes):
         if pos_label not in list(classes):
-            raise ValueError(
-                f"pos_label={pos_label} is not a valid label: {classes}"
-            )
+            raise ValueError(f"pos_label={pos_label} is not a valid label: {classes}")
 
     def _select_proba_binary(self, y_pred, classes):
         """Select the column of the positive label in `y_pred` when
@@ -161,17 +178,20 @@ class _BaseScorer:
         err_msg = (
             f"Got predict_proba of shape {y_pred.shape}, but need "
             f"classifier with two classes for {self._score_func.__name__} "
-            f"scoring"
+            "scoring"
         )
         raise ValueError(err_msg)
 
     def __repr__(self):
-        kwargs_string = "".join([", %s=%s" % (str(k), str(v))
-                                 for k, v in self._kwargs.items()])
-        return ("make_scorer(%s%s%s%s)"
-                % (self._score_func.__name__,
-                   "" if self._sign > 0 else ", greater_is_better=False",
-                   self._factory_args(), kwargs_string))
+        kwargs_string = "".join(
+            [", %s=%s" % (str(k), str(v)) for k, v in self._kwargs.items()]
+        )
+        return "make_scorer(%s%s%s%s)" % (
+            self._score_func.__name__,
+            "" if self._sign > 0 else ", greater_is_better=False",
+            self._factory_args(),
+            kwargs_string,
+        )
 
     def __call__(self, estimator, X, y_true, sample_weight=None):
         """Evaluate predicted target values for X relative to y_true.
@@ -196,8 +216,13 @@ class _BaseScorer:
         score : float
             Score function applied to prediction of estimator on X.
         """
-        return self._score(partial(_cached_call, None), estimator, X, y_true,
-                           sample_weight=sample_weight)
+        return self._score(
+            partial(_cached_call, None),
+            estimator,
+            X,
+            y_true,
+            sample_weight=sample_weight,
+        )
 
     def _factory_args(self):
         """Return non-default make_scorer arguments for repr."""
@@ -235,12 +260,11 @@ class _PredictScorer(_BaseScorer):
 
         y_pred = method_caller(estimator, "predict", X)
         if sample_weight is not None:
-            return self._sign * self._score_func(y_true, y_pred,
-                                                 sample_weight=sample_weight,
-                                                 **self._kwargs)
+            return self._sign * self._score_func(
+                y_true, y_pred, sample_weight=sample_weight, **self._kwargs
+            )
         else:
-            return self._sign * self._score_func(y_true, y_pred,
-                                                 **self._kwargs)
+            return self._sign * self._score_func(y_true, y_pred, **self._kwargs)
 
 
 class _ProbaScorer(_BaseScorer):
@@ -281,9 +305,9 @@ class _ProbaScorer(_BaseScorer):
             # Thus, we need to check for the shape of `y_pred`.
             y_pred = self._select_proba_binary(y_pred, clf.classes_)
         if sample_weight is not None:
-            return self._sign * self._score_func(y, y_pred,
-                                                 sample_weight=sample_weight,
-                                                 **self._kwargs)
+            return self._sign * self._score_func(
+                y, y_pred, sample_weight=sample_weight, **self._kwargs
+            )
         else:
             return self._sign * self._score_func(y, y_pred, **self._kwargs)
 
@@ -337,9 +361,7 @@ class _ThresholdScorer(_BaseScorer):
                     # For multi-output multi-class estimator
                     y_pred = np.vstack([p for p in y_pred]).T
                 elif y_type == "binary" and "pos_label" in self._kwargs:
-                    self._check_pos_label(
-                        self._kwargs["pos_label"], clf.classes_
-                    )
+                    self._check_pos_label(self._kwargs["pos_label"], clf.classes_)
                     if self._kwargs["pos_label"] == clf.classes_[0]:
                         # The implicit positive class of the binary classifier
                         # does not match `pos_label`: we need to invert the
@@ -355,9 +377,9 @@ class _ThresholdScorer(_BaseScorer):
                     y_pred = np.vstack([p[:, -1] for p in y_pred]).T
 
         if sample_weight is not None:
-            return self._sign * self._score_func(y, y_pred,
-                                                 sample_weight=sample_weight,
-                                                 **self._kwargs)
+            return self._sign * self._score_func(
+                y, y_pred, sample_weight=sample_weight, **self._kwargs
+            )
         else:
             return self._sign * self._score_func(y, y_pred, **self._kwargs)
 
@@ -369,6 +391,8 @@ def get_scorer(scoring):
     """Get a scorer from string.
 
     Read more in the :ref:`User Guide <scoring_parameter>`.
+    :func:`~sklearn.metrics.get_scorer_names` can be used to retrieve the names
+    of all available scorers.
 
     Parameters
     ----------
@@ -379,14 +403,22 @@ def get_scorer(scoring):
     -------
     scorer : callable
         The scorer.
+
+    Notes
+    -----
+    When passed a string, this function always returns a copy of the scorer
+    object. Calling `get_scorer` twice for the same scorer results in two
+    separate scorer objects.
     """
     if isinstance(scoring, str):
         try:
-            scorer = SCORERS[scoring]
+            scorer = copy.deepcopy(_SCORERS[scoring])
         except KeyError:
-            raise ValueError('%r is not a valid scoring value. '
-                             'Use sorted(sklearn.metrics.SCORERS.keys()) '
-                             'to get valid options.' % scoring)
+            raise ValueError(
+                "%r is not a valid scoring value. "
+                "Use sklearn.metrics.get_scorer_names() "
+                "to get valid options." % scoring
+            )
     else:
         scorer = scoring
     return scorer
@@ -397,7 +429,6 @@ def _passthrough_scorer(estimator, *args, **kwargs):
     return estimator.score(*args, **kwargs)
 
 
-@_deprecate_positional_args
 def check_scoring(estimator, scoring=None, *, allow_none=False):
     """Determine scorer from user options.
 
@@ -412,6 +443,7 @@ def check_scoring(estimator, scoring=None, *, allow_none=False):
         A string (see model evaluation documentation) or
         a scorer callable object / function with signature
         ``scorer(estimator, X, y)``.
+        If None, the provided estimator object's `score` method is used.
 
     allow_none : bool, default=False
         If no scoring is specified and the estimator has no score function, we
@@ -423,41 +455,51 @@ def check_scoring(estimator, scoring=None, *, allow_none=False):
         A scorer callable object / function with signature
         ``scorer(estimator, X, y)``.
     """
-    if not hasattr(estimator, 'fit'):
-        raise TypeError("estimator should be an estimator implementing "
-                        "'fit' method, %r was passed" % estimator)
+    if not hasattr(estimator, "fit"):
+        raise TypeError(
+            "estimator should be an estimator implementing 'fit' method, %r was passed"
+            % estimator
+        )
     if isinstance(scoring, str):
         return get_scorer(scoring)
     elif callable(scoring):
         # Heuristic to ensure user has not passed a metric
-        module = getattr(scoring, '__module__', None)
-        if hasattr(module, 'startswith') and \
-           module.startswith('sklearn.metrics.') and \
-           not module.startswith('sklearn.metrics._scorer') and \
-           not module.startswith('sklearn.metrics.tests.'):
-            raise ValueError('scoring value %r looks like it is a metric '
-                             'function rather than a scorer. A scorer should '
-                             'require an estimator as its first parameter. '
-                             'Please use `make_scorer` to convert a metric '
-                             'to a scorer.' % scoring)
+        module = getattr(scoring, "__module__", None)
+        if (
+            hasattr(module, "startswith")
+            and module.startswith("sklearn.metrics.")
+            and not module.startswith("sklearn.metrics._scorer")
+            and not module.startswith("sklearn.metrics.tests.")
+        ):
+            raise ValueError(
+                "scoring value %r looks like it is a metric "
+                "function rather than a scorer. A scorer should "
+                "require an estimator as its first parameter. "
+                "Please use `make_scorer` to convert a metric "
+                "to a scorer." % scoring
+            )
         return get_scorer(scoring)
     elif scoring is None:
-        if hasattr(estimator, 'score'):
+        if hasattr(estimator, "score"):
             return _passthrough_scorer
         elif allow_none:
             return None
         else:
             raise TypeError(
                 "If no scoring is specified, the estimator passed should "
-                "have a 'score' method. The estimator %r does not."
-                % estimator)
+                "have a 'score' method. The estimator %r does not." % estimator
+            )
     elif isinstance(scoring, Iterable):
-        raise ValueError("For evaluating multiple scores, use "
-                         "sklearn.model_selection.cross_validate instead. "
-                         "{0} was passed.".format(scoring))
+        raise ValueError(
+            "For evaluating multiple scores, use "
+            "sklearn.model_selection.cross_validate instead. "
+            "{0} was passed.".format(scoring)
+        )
     else:
-        raise ValueError("scoring value should either be a callable, string or"
-                         " None. %r was passed" % scoring)
+        raise ValueError(
+            "scoring value should either be a callable, string or None. %r was passed"
+            % scoring
+        )
 
 
 def _check_multimetric_scoring(estimator, scoring):
@@ -489,54 +531,69 @@ def _check_multimetric_scoring(estimator, scoring):
     err_msg_generic = (
         f"scoring is invalid (got {scoring!r}). Refer to the "
         "scoring glossary for details: "
-        "https://scikit-learn.org/stable/glossary.html#term-scoring")
+        "https://scikit-learn.org/stable/glossary.html#term-scoring"
+    )
 
     if isinstance(scoring, (list, tuple, set)):
-        err_msg = ("The list/tuple elements must be unique "
-                   "strings of predefined scorers. ")
-        invalid = False
+        err_msg = (
+            "The list/tuple elements must be unique strings of predefined scorers. "
+        )
         try:
             keys = set(scoring)
-        except TypeError:
-            invalid = True
-        if invalid:
-            raise ValueError(err_msg)
+        except TypeError as e:
+            raise ValueError(err_msg) from e
 
         if len(keys) != len(scoring):
-            raise ValueError(f"{err_msg} Duplicate elements were found in"
-                             f" the given list. {scoring!r}")
+            raise ValueError(
+                f"{err_msg} Duplicate elements were found in"
+                f" the given list. {scoring!r}"
+            )
         elif len(keys) > 0:
             if not all(isinstance(k, str) for k in keys):
                 if any(callable(k) for k in keys):
-                    raise ValueError(f"{err_msg} One or more of the elements "
-                                     "were callables. Use a dict of score "
-                                     "name mapped to the scorer callable. "
-                                     f"Got {scoring!r}")
+                    raise ValueError(
+                        f"{err_msg} One or more of the elements "
+                        "were callables. Use a dict of score "
+                        "name mapped to the scorer callable. "
+                        f"Got {scoring!r}"
+                    )
                 else:
-                    raise ValueError(f"{err_msg} Non-string types were found "
-                                     f"in the given list. Got {scoring!r}")
-            scorers = {scorer: check_scoring(estimator, scoring=scorer)
-                       for scorer in scoring}
+                    raise ValueError(
+                        f"{err_msg} Non-string types were found "
+                        f"in the given list. Got {scoring!r}"
+                    )
+            scorers = {
+                scorer: check_scoring(estimator, scoring=scorer) for scorer in scoring
+            }
         else:
             raise ValueError(f"{err_msg} Empty list was given. {scoring!r}")
 
     elif isinstance(scoring, dict):
         keys = set(scoring)
         if not all(isinstance(k, str) for k in keys):
-            raise ValueError("Non-string types were found in the keys of "
-                             f"the given dict. scoring={scoring!r}")
+            raise ValueError(
+                "Non-string types were found in the keys of "
+                f"the given dict. scoring={scoring!r}"
+            )
         if len(keys) == 0:
             raise ValueError(f"An empty dict was passed. {scoring!r}")
-        scorers = {key: check_scoring(estimator, scoring=scorer)
-                   for key, scorer in scoring.items()}
+        scorers = {
+            key: check_scoring(estimator, scoring=scorer)
+            for key, scorer in scoring.items()
+        }
     else:
         raise ValueError(err_msg_generic)
     return scorers
 
 
-@_deprecate_positional_args
-def make_scorer(score_func, *, greater_is_better=True, needs_proba=False,
-                needs_threshold=False, **kwargs):
+def make_scorer(
+    score_func,
+    *,
+    greater_is_better=True,
+    needs_proba=False,
+    needs_threshold=False,
+    **kwargs,
+):
     """Make a scorer from a performance metric or loss function.
 
     This factory function wraps scoring functions for use in
@@ -544,8 +601,8 @@ def make_scorer(score_func, *, greater_is_better=True, needs_proba=False,
     :func:`~sklearn.model_selection.cross_val_score`.
     It takes a score function, such as :func:`~sklearn.metrics.accuracy_score`,
     :func:`~sklearn.metrics.mean_squared_error`,
-    :func:`~sklearn.metrics.adjusted_rand_index` or
-    :func:`~sklearn.metrics.average_precision`
+    :func:`~sklearn.metrics.adjusted_rand_score` or
+    :func:`~sklearn.metrics.average_precision_score`
     and returns a callable that scores an estimator's output.
     The signature of the call is `(estimator, X, y)` where `estimator`
     is the model to be evaluated, `X` is the data and `y` is the
@@ -557,41 +614,52 @@ def make_scorer(score_func, *, greater_is_better=True, needs_proba=False,
     ----------
     score_func : callable
         Score function (or loss function) with signature
-        ``score_func(y, y_pred, **kwargs)``.
+        `score_func(y, y_pred, **kwargs)`.
 
     greater_is_better : bool, default=True
-        Whether score_func is a score function (default), meaning high is good,
-        or a loss function, meaning low is good. In the latter case, the
-        scorer object will sign-flip the outcome of the score_func.
+        Whether `score_func` is a score function (default), meaning high is
+        good, or a loss function, meaning low is good. In the latter case, the
+        scorer object will sign-flip the outcome of the `score_func`.
 
     needs_proba : bool, default=False
-        Whether score_func requires predict_proba to get probability estimates
-        out of a classifier.
+        Whether `score_func` requires `predict_proba` to get probability
+        estimates out of a classifier.
 
         If True, for binary `y_true`, the score function is supposed to accept
         a 1D `y_pred` (i.e., probability of the positive class, shape
         `(n_samples,)`).
 
     needs_threshold : bool, default=False
-        Whether score_func takes a continuous decision certainty.
+        Whether `score_func` takes a continuous decision certainty.
         This only works for binary classification using estimators that
-        have either a decision_function or predict_proba method.
+        have either a `decision_function` or `predict_proba` method.
 
         If True, for binary `y_true`, the score function is supposed to accept
         a 1D `y_pred` (i.e., probability of the positive class or the decision
         function, shape `(n_samples,)`).
 
-        For example ``average_precision`` or the area under the roc curve
+        For example `average_precision` or the area under the roc curve
         can not be computed using discrete predictions alone.
 
     **kwargs : additional arguments
-        Additional parameters to be passed to score_func.
+        Additional parameters to be passed to `score_func`.
 
     Returns
     -------
     scorer : callable
         Callable object that returns a scalar score; greater is better.
 
+    Notes
+    -----
+    If `needs_proba=False` and `needs_threshold=False`, the score
+    function is supposed to accept the output of :term:`predict`. If
+    `needs_proba=True`, the score function is supposed to accept the
+    output of :term:`predict_proba` (For binary `y_true`, the score function is
+    supposed to accept probability of the positive class). If
+    `needs_threshold=True`, the score function is supposed to accept the
+    output of :term:`decision_function` or :term:`predict_proba` when
+    :term:`decision_function` is not present.
+
     Examples
     --------
     >>> from sklearn.metrics import fbeta_score, make_scorer
@@ -602,21 +670,12 @@ def make_scorer(score_func, *, greater_is_better=True, needs_proba=False,
     >>> from sklearn.svm import LinearSVC
     >>> grid = GridSearchCV(LinearSVC(), param_grid={'C': [1, 10]},
     ...                     scoring=ftwo_scorer)
-
-    Notes
-    -----
-    If `needs_proba=False` and `needs_threshold=False`, the score
-    function is supposed to accept the output of :term:`predict`. If
-    `needs_proba=True`, the score function is supposed to accept the
-    output of :term:`predict_proba` (For binary `y_true`, the score function is
-    supposed to accept probability of the positive class). If
-    `needs_threshold=True`, the score function is supposed to accept the
-    output of :term:`decision_function`.
     """
     sign = 1 if greater_is_better else -1
     if needs_proba and needs_threshold:
-        raise ValueError("Set either needs_proba or needs_threshold to True,"
-                         " but not both.")
+        raise ValueError(
+            "Set either needs_proba or needs_threshold to True, but not both."
+        )
     if needs_proba:
         cls = _ProbaScorer
     elif needs_threshold:
@@ -629,22 +688,23 @@ def make_scorer(score_func, *, greater_is_better=True, needs_proba=False,
 # Standard regression scores
 explained_variance_scorer = make_scorer(explained_variance_score)
 r2_scorer = make_scorer(r2_score)
-max_error_scorer = make_scorer(max_error,
-                               greater_is_better=False)
-neg_mean_squared_error_scorer = make_scorer(mean_squared_error,
-                                            greater_is_better=False)
-neg_mean_squared_log_error_scorer = make_scorer(mean_squared_log_error,
-                                                greater_is_better=False)
-neg_mean_absolute_error_scorer = make_scorer(mean_absolute_error,
-                                             greater_is_better=False)
+max_error_scorer = make_scorer(max_error, greater_is_better=False)
+neg_mean_squared_error_scorer = make_scorer(mean_squared_error, greater_is_better=False)
+neg_mean_squared_log_error_scorer = make_scorer(
+    mean_squared_log_error, greater_is_better=False
+)
+neg_mean_absolute_error_scorer = make_scorer(
+    mean_absolute_error, greater_is_better=False
+)
 neg_mean_absolute_percentage_error_scorer = make_scorer(
     mean_absolute_percentage_error, greater_is_better=False
 )
-neg_median_absolute_error_scorer = make_scorer(median_absolute_error,
-                                               greater_is_better=False)
-neg_root_mean_squared_error_scorer = make_scorer(mean_squared_error,
-                                                 greater_is_better=False,
-                                                 squared=False)
+neg_median_absolute_error_scorer = make_scorer(
+    median_absolute_error, greater_is_better=False
+)
+neg_root_mean_squared_error_scorer = make_scorer(
+    mean_squared_error, greater_is_better=False, squared=False
+)
 neg_mean_poisson_deviance_scorer = make_scorer(
     mean_poisson_deviance, greater_is_better=False
 )
@@ -656,35 +716,33 @@ neg_mean_gamma_deviance_scorer = make_scorer(
 # Standard Classification Scores
 accuracy_scorer = make_scorer(accuracy_score)
 balanced_accuracy_scorer = make_scorer(balanced_accuracy_score)
+matthews_corrcoef_scorer = make_scorer(matthews_corrcoef)
 
 # Score functions that need decision values
-top_k_accuracy_scorer = make_scorer(top_k_accuracy_score,
-                                    greater_is_better=True,
-                                    needs_threshold=True)
-roc_auc_scorer = make_scorer(roc_auc_score, greater_is_better=True,
-                             needs_threshold=True)
-average_precision_scorer = make_scorer(average_precision_score,
-                                       needs_threshold=True)
-roc_auc_ovo_scorer = make_scorer(roc_auc_score, needs_proba=True,
-                                 multi_class='ovo')
-roc_auc_ovo_weighted_scorer = make_scorer(roc_auc_score, needs_proba=True,
-                                          multi_class='ovo',
-                                          average='weighted')
-roc_auc_ovr_scorer = make_scorer(roc_auc_score, needs_proba=True,
-                                 multi_class='ovr')
-roc_auc_ovr_weighted_scorer = make_scorer(roc_auc_score, needs_proba=True,
-                                          multi_class='ovr',
-                                          average='weighted')
+top_k_accuracy_scorer = make_scorer(
+    top_k_accuracy_score, greater_is_better=True, needs_threshold=True
+)
+roc_auc_scorer = make_scorer(
+    roc_auc_score, greater_is_better=True, needs_threshold=True
+)
+average_precision_scorer = make_scorer(average_precision_score, needs_threshold=True)
+roc_auc_ovo_scorer = make_scorer(roc_auc_score, needs_proba=True, multi_class="ovo")
+roc_auc_ovo_weighted_scorer = make_scorer(
+    roc_auc_score, needs_proba=True, multi_class="ovo", average="weighted"
+)
+roc_auc_ovr_scorer = make_scorer(roc_auc_score, needs_proba=True, multi_class="ovr")
+roc_auc_ovr_weighted_scorer = make_scorer(
+    roc_auc_score, needs_proba=True, multi_class="ovr", average="weighted"
+)
 
 # Score function for probabilistic classification
-neg_log_loss_scorer = make_scorer(log_loss, greater_is_better=False,
-                                  needs_proba=True)
-neg_brier_score_scorer = make_scorer(brier_score_loss,
-                                     greater_is_better=False,
-                                     needs_proba=True)
-brier_score_loss_scorer = make_scorer(brier_score_loss,
-                                      greater_is_better=False,
-                                      needs_proba=True)
+neg_log_loss_scorer = make_scorer(log_loss, greater_is_better=False, needs_proba=True)
+neg_brier_score_scorer = make_scorer(
+    brier_score_loss, greater_is_better=False, needs_proba=True
+)
+brier_score_loss_scorer = make_scorer(
+    brier_score_loss, greater_is_better=False, needs_proba=True
+)
 
 
 # Clustering scores
@@ -699,45 +757,80 @@ normalized_mutual_info_scorer = make_scorer(normalized_mutual_info_score)
 fowlkes_mallows_scorer = make_scorer(fowlkes_mallows_score)
 
 
-SCORERS = dict(explained_variance=explained_variance_scorer,
-               r2=r2_scorer,
-               max_error=max_error_scorer,
-               neg_median_absolute_error=neg_median_absolute_error_scorer,
-               neg_mean_absolute_error=neg_mean_absolute_error_scorer,
-               neg_mean_absolute_percentage_error=neg_mean_absolute_percentage_error_scorer,  # noqa
-               neg_mean_squared_error=neg_mean_squared_error_scorer,
-               neg_mean_squared_log_error=neg_mean_squared_log_error_scorer,
-               neg_root_mean_squared_error=neg_root_mean_squared_error_scorer,
-               neg_mean_poisson_deviance=neg_mean_poisson_deviance_scorer,
-               neg_mean_gamma_deviance=neg_mean_gamma_deviance_scorer,
-               accuracy=accuracy_scorer,
-               top_k_accuracy=top_k_accuracy_scorer,
-               roc_auc=roc_auc_scorer,
-               roc_auc_ovr=roc_auc_ovr_scorer,
-               roc_auc_ovo=roc_auc_ovo_scorer,
-               roc_auc_ovr_weighted=roc_auc_ovr_weighted_scorer,
-               roc_auc_ovo_weighted=roc_auc_ovo_weighted_scorer,
-               balanced_accuracy=balanced_accuracy_scorer,
-               average_precision=average_precision_scorer,
-               neg_log_loss=neg_log_loss_scorer,
-               neg_brier_score=neg_brier_score_scorer,
-               # Cluster metrics that use supervised evaluation
-               adjusted_rand_score=adjusted_rand_scorer,
-               rand_score=rand_scorer,
-               homogeneity_score=homogeneity_scorer,
-               completeness_score=completeness_scorer,
-               v_measure_score=v_measure_scorer,
-               mutual_info_score=mutual_info_scorer,
-               adjusted_mutual_info_score=adjusted_mutual_info_scorer,
-               normalized_mutual_info_score=normalized_mutual_info_scorer,
-               fowlkes_mallows_score=fowlkes_mallows_scorer)
+# TODO(1.3) Remove
+class _DeprecatedScorers(dict):
+    """A temporary class to deprecate SCORERS."""
+
+    def __getitem__(self, item):
+        warnings.warn(
+            "sklearn.metrics.SCORERS is deprecated and will be removed in v1.3. "
+            "Please use sklearn.metrics.get_scorer_names to get a list of available "
+            "scorers and sklearn.metrics.get_metric to get scorer.",
+            FutureWarning,
+        )
+        return super().__getitem__(item)
 
 
-for name, metric in [('precision', precision_score),
-                     ('recall', recall_score), ('f1', f1_score),
-                     ('jaccard', jaccard_score)]:
-    SCORERS[name] = make_scorer(metric, average='binary')
-    for average in ['macro', 'micro', 'samples', 'weighted']:
-        qualified_name = '{0}_{1}'.format(name, average)
-        SCORERS[qualified_name] = make_scorer(metric, pos_label=None,
-                                              average=average)
+_SCORERS = dict(
+    explained_variance=explained_variance_scorer,
+    r2=r2_scorer,
+    max_error=max_error_scorer,
+    matthews_corrcoef=matthews_corrcoef_scorer,
+    neg_median_absolute_error=neg_median_absolute_error_scorer,
+    neg_mean_absolute_error=neg_mean_absolute_error_scorer,
+    neg_mean_absolute_percentage_error=neg_mean_absolute_percentage_error_scorer,  # noqa
+    neg_mean_squared_error=neg_mean_squared_error_scorer,
+    neg_mean_squared_log_error=neg_mean_squared_log_error_scorer,
+    neg_root_mean_squared_error=neg_root_mean_squared_error_scorer,
+    neg_mean_poisson_deviance=neg_mean_poisson_deviance_scorer,
+    neg_mean_gamma_deviance=neg_mean_gamma_deviance_scorer,
+    accuracy=accuracy_scorer,
+    top_k_accuracy=top_k_accuracy_scorer,
+    roc_auc=roc_auc_scorer,
+    roc_auc_ovr=roc_auc_ovr_scorer,
+    roc_auc_ovo=roc_auc_ovo_scorer,
+    roc_auc_ovr_weighted=roc_auc_ovr_weighted_scorer,
+    roc_auc_ovo_weighted=roc_auc_ovo_weighted_scorer,
+    balanced_accuracy=balanced_accuracy_scorer,
+    average_precision=average_precision_scorer,
+    neg_log_loss=neg_log_loss_scorer,
+    neg_brier_score=neg_brier_score_scorer,
+    # Cluster metrics that use supervised evaluation
+    adjusted_rand_score=adjusted_rand_scorer,
+    rand_score=rand_scorer,
+    homogeneity_score=homogeneity_scorer,
+    completeness_score=completeness_scorer,
+    v_measure_score=v_measure_scorer,
+    mutual_info_score=mutual_info_scorer,
+    adjusted_mutual_info_score=adjusted_mutual_info_scorer,
+    normalized_mutual_info_score=normalized_mutual_info_scorer,
+    fowlkes_mallows_score=fowlkes_mallows_scorer,
+)
+
+
+def get_scorer_names():
+    """Get the names of all available scorers.
+
+    These names can be passed to :func:`~sklearn.metrics.get_scorer` to
+    retrieve the scorer object.
+
+    Returns
+    -------
+    list of str
+        Names of all available scorers.
+    """
+    return sorted(_SCORERS.keys())
+
+
+for name, metric in [
+    ("precision", precision_score),
+    ("recall", recall_score),
+    ("f1", f1_score),
+    ("jaccard", jaccard_score),
+]:
+    _SCORERS[name] = make_scorer(metric, average="binary")
+    for average in ["macro", "micro", "samples", "weighted"]:
+        qualified_name = "{0}_{1}".format(name, average)
+        _SCORERS[qualified_name] = make_scorer(metric, pos_label=None, average=average)
+
+SCORERS = _DeprecatedScorers(_SCORERS)
